<?php

declare(strict_types=1);

namespace Drupal\lms_answer_plugins\Plugin\ActivityAnswer;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\lms\Attribute\ActivityAnswer;
use Drupal\lms\Entity\Answer;
use Drupal\lms_answer_plugins\Plugin\TrueFalseBase;

/**
 * Long Answer activity plugin.
 */
#[ActivityAnswer(
  id: 'true_false_feedback',
  name: new TranslatableMarkup('True / false with feedback'),
)]
final class TrueFalseFeedback extends TrueFalseBase {

  /**
   * {@inheritdoc}
   */
  public function answeringForm(array &$form, FormStateInterface $form_state, Answer $answer): void {
    parent::answeringForm($form, $form_state, $answer);
    $activity = $answer->getActivity();
    $feedback_field = $activity->get('answer_feedback');
    if ($feedback_field->isEmpty()) {
      return;
    }

    $feedback = $feedback_field->getValue();

    $form['answer']['#ajax'] = [
      'callback' => [$this, 'getFeedback'],
      'wrapper' => 'feedback-wrapper',
    ];
    $form['answer']['feedback'] = [
      '#type' => 'container',
      '#attributes' => ['id' => $form['answer']['#ajax']['wrapper']],
    ];

    $score = NULL;
    $answer_value = $form_state->getValue('answer');
    if ($answer_value !== NULL) {
      $answer->setData(['answer' => $answer_value]);
    }
    elseif (\count($answer->getData()) === 0) {
      return;
    }

    $score = $this->getScore($answer);
    $class = $score > 0 ? 'correct' : 'incorrect';
    $form['answer']['feedback']['#attributes']['class'] = [$class];
    $form['answer']['feedback']['value'] = [
      '#markup' => $feedback[$score]['value'],
    ];
  }

  /**
   * Feedback callback.
   */
  public function getFeedback(array $form, FormStateInterface $form_state): array {
    return $form['answer']['feedback'];
  }

}
