<?php

declare(strict_types=1);

namespace Drupal\lms\Hook;

use Drupal\Core\Entity\EntityFormInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\lms\DataIntegrityChecker;
use Drupal\lms\Entity\Bundle\Course;
use Drupal\lms\Form\DataIntegrityWarningTrait;

/**
 * Simple form alter hooks.
 */
final class GroupFormAlter {

  use StringTranslationTrait;
  use DataIntegrityWarningTrait;

  public function __construct(
    protected DataIntegrityChecker $integrityChecker,
  ) {}

  /**
   * Form alter hook.
   */
  #[Hook('form_group_form_alter')]
  public function groupFormAlter(array &$form, FormStateInterface $form_state): void {
    $form_object = $form_state->getFormObject();
    \assert($form_object instanceof EntityFormInterface);
    $group = $form_object->getEntity();
    if (!$group instanceof Course) {
      return;
    }
    $in_progress = $this->integrityChecker->checkCourseProgress($group);
    if ($in_progress) {
      $affected_fields = [
        'lessons',
      ];
      foreach ($affected_fields as $field) {
        $this->addDataWarning($form[$field], $this->t('This course has already been started by certain students, changing the field below may cause their current progress to become inconsistent with the new value.'));
      }
    }
  }

}
